@@ -310,6 +310,8 @@ namespace internal {
 
     inline node_connection create_node_connection(const nlohmann::json& args)
     {
+        assertion(json_obj_has_member(args["config"], "keras_history"),
+            "No keras_history on node connection. Constant-value tensors are not supported.");
         const std::vector<nlohmann::json> keras_history = args["config"]["keras_history"];
         assertion(keras_history.size() >= 3, "invalid number of items in keras_history");
         const std::string layer_id = keras_history[0];
@@ -1032,7 +1034,7 @@ namespace internal {
         const get_param_f&, const nlohmann::json& data,
         const std::string& name)
     {
-        float_type negative_slope = 0.3f;
+        float_type negative_slope = 0.2f;
         if (json_obj_has_member(data, "config") && json_obj_has_member(data["config"], "negative_slope")) {
             negative_slope = data["config"]["negative_slope"];
         }
@@ -1070,7 +1072,11 @@ namespace internal {
         const auto axex = create_vector<int>(create_int, data["config"]["axis"]);
         const float_vec mean = decode_floats(get_param(name, "mean"));
         const float_vec variance = decode_floats(get_param(name, "variance"));
-        return std::make_shared<normalization_layer>(name, axex, mean, variance);
+        bool invert = false;
+        if (json_obj_has_member(data["config"], "invert")) {
+            invert = data["config"]["invert"];
+        }
+        return std::make_shared<normalization_layer>(name, axex, mean, variance, invert);
     }
 
     inline layer_ptr create_category_encoding_layer(
