@@ -213,6 +213,7 @@ def get_test_model_exhaustive() -> Model:
     outputs.append(GlobalAveragePooling1D(keepdims=True)(inputs[6]))
 
     outputs.append(Normalization(axis=None, mean=2.1, variance=2.2)(inputs[4]))
+    outputs.append(Normalization(axis=None, mean=2.1, variance=2.2, invert=True)(inputs[4]))
     # outputs.append(Normalization(axis=-1, mean=2.1, variance=2.2)(inputs[6]))  # No longer supported in TensorFlow 2.16
     outputs.append(Normalization(axis=-1, mean=2.1, variance=2.2)(inputs[46]))
     outputs.append(Normalization(axis=1, mean=2.1, variance=2.2)(inputs[46]))
@@ -610,6 +611,7 @@ def get_test_model_exhaustive() -> Model:
         Activation('squareplus')(inputs[25]),
         Activation('tanh')(inputs[25]),
         Activation('tanh_shrink')(inputs[25]),
+        Activation('leaky_relu')(inputs[25]),
         LeakyReLU(name="real_LeakyReLU_layer", negative_slope=0.5)(inputs[25]),
         ReLU(name="real_ReLU_layer_1")(inputs[25]),
         ReLU(name="real_ReLU_layer_2", max_value=0.4, negative_slope=1.1, threshold=0.3)(inputs[25]),
